@@ -2956,7 +2956,11 @@ bool ScriptInterp::scrConst(void)
 	char *sym = getOption(NULL);
 	char *val;
 	int max = getSymbolSize();
+#ifdef	__PEDANTIC__
+	char buffer[1024];
+#else
 	char buffer[max + 1];
+#endif
 	int count = 0;
 	int idx = 0, len = 0;
 	Line *line = getScript();
