@@ -515,7 +515,7 @@ void ScriptSymbol::commit(Symbol *sym)
 	if(sym->flags.type != INDEX)
 		return;
 
-	strcpy(array, sym->id);
+	snprintf(array, sizeof(array) - 6, sym->id);
 	id = strrchr(array, '.');
 	if(!id)
 		return;
@@ -1209,7 +1209,7 @@ Keydata(symset)
 #endif
 	for(;;)
 	{
-		scrname = (char *)dir.getName();
+		scrname = const_cast<char*>(dir.getName());
 		if(!scrname)
 			break;
 		ext = strchr(scrname, '.');
@@ -1612,7 +1612,11 @@ Script::Name *ScriptImage::getScript(const char *name)
 
 int ScriptImage::compile(const char *scrname)
 {
+#ifdef	__PEDANTIC__
+	char buffer[256];
+#else
 	char buffer[strlen(scrname) + 1];
+#endif
 	char *token;
 	char *ext;
 
@@ -1632,7 +1636,11 @@ int ScriptImage::compile(const char *scrname)
 
 Script::Name *ScriptImage::include(const char *scrname)
 {
+#ifdef	__PEDANTIC__
+	char buffer[256];
+#else
 	char buffer[strlen(scrname) + 1];
+#endif
 	char *token;
 	char *ext;
 	Name *inc;
